@@ -1,9 +1,9 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 
 import os
 
 from fixtures import Fixtures
-from utils    import mkfreshdir, run_bzr
+from utils    import run_bzr
 
 
 class BzrFixtures(Fixtures):
@@ -24,10 +24,11 @@ class BzrFixtures(Fixtures):
         os.chdir(self.repo_path)
         self.safe_run('init')
         self.safe_run('whoami "%s"' % self.name_and_email)
-        self.wd = self.repo_path
+        self.wdir = self.repo_path
         print("created repo %s" % self.repo_path)
 
-    def record_rev(self, wd, rev_num):
+    def record_rev(self, *args):
+        rev_num = args[0]
         self.revs[rev_num] = str(rev_num)
         self.scmlogs.annotate("Recorded rev %d" % rev_num)
 
